@@ -1,9 +1,13 @@
 package Telegram::Bot::Brain;
-$Telegram::Bot::Brain::VERSION = '0.009';
+$Telegram::Bot::Brain::VERSION = '0.010';
 # ABSTRACT: A base class to make your very own Telegram bot
 
 
 use Mojo::Base -base;
+
+use strict;
+use warnings;
+
 use Mojo::IOLoop;
 use Mojo::UserAgent;
 use Carp qw/croak/;
@@ -174,7 +178,7 @@ Telegram::Bot::Brain - A base class to make your very own Telegram bot
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
@@ -220,18 +224,24 @@ Respond to messages we receive. It takes two arguments
 
 =item *
 
-a CODEREF to be executed to evaluate if we should respond to this message or a regular expression to be matched against
+CODEREF or regular expression
+
+The coderef should return a true or false value, based on the input message. It is called
+as an object method on your subclass, with the first argument being the message object.
+If you instead supply a regular expression, the message object's text component is checked
+against it.
 
 =item *
 
-a CODEREF to be executed if the previous criteria was true
+CODEREF to be executed if the previous criteria was true
+
+As above, it is called as an object method, and the first argument is the message object
+that you are responding to.
 
 =item *
 
 an optional hashref of arguments
 
-=end
-
 =back
 
 Each CODEREF is passed two arguments, this C<Telegram::Bot::Brain> object, and
