@@ -1,5 +1,7 @@
 package Telegram::Bot::Object::Base;
-$Telegram::Bot::Object::Base::VERSION = '0.009';
+$Telegram::Bot::Object::Base::VERSION = '0.010';
+# ABSTRACT: The base class for all Telegram::Bot::Object objects
+
 use Mojo::Base -base;
 
 sub send_method {
@@ -62,11 +64,11 @@ __END__
 
 =head1 NAME
 
-Telegram::Bot::Object::Base
+Telegram::Bot::Object::Base - The base class for all Telegram::Bot::Object objects
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 AUTHOR
 
